@@ -14,43 +14,36 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+import sys
+from typing import List, Optional
+
 from . import Merge3
 
 
-def main(argv=None):
+def main(argv: Optional[List[str]] = None) -> int:
     import argparse
 
     parser = argparse.ArgumentParser()
     # as for diff3 and meld the syntax is "MINE BASE OTHER"
-    parser.add_argument(
-        'mine', type=argparse.FileType('rt'),
-        help='My text')
-    parser.add_argument(
-        'base', type=argparse.FileType('rt'),
-        help='Base text')
-    parser.add_argument(
-        'other', type=argparse.FileType('rt'),
-        help='Other text')
-    parser.add_argument(
-        '--annotated', action='store_true',
-        help='Show annotated view.')
+    parser.add_argument("mine", type=argparse.FileType("rt"), help="My text")
+    parser.add_argument("base", type=argparse.FileType("rt"), help="Base text")
+    parser.add_argument("other", type=argparse.FileType("rt"), help="Other text")
+    parser.add_argument("--annotated", action="store_true", help="Show annotated view.")
 
     args = parser.parse_args(argv)
 
-    m3 = Merge3(
-        args.base.readlines(),
-        args.mine.readlines(),
-        args.other.readlines())
+    m3 = Merge3(args.base.readlines(), args.mine.readlines(), args.other.readlines())
 
     if args.annotated:
         sys.stdout.writelines(m3.merge_annotated())
     else:
         sys.stdout.writelines(
             m3.merge_lines(
-                name_a=args.mine.name, name_b=args.other.name,
-                name_base=args.base.name))
+                name_a=args.mine.name, name_b=args.other.name, name_base=args.base.name
+            )
+        )
+    return 0
 
 
-if __name__ == '__main__':
-    import sys
+if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
